from typing import Final

__title__: Final = "requests"
__description__: Final[str]
__url__: Final[str]
__version__: Final[str]
__build__: Final[int]
__author__: Final[str]
__author_email__: Final[str]
__license__: Final[str]
__copyright__: Final[str]
__cake__: Final[str]
